transformer

|  | ## Cheshire3: transformer Module

Module transformer

Classes | [hide private]
FilepathTransformer | Returns record.id as an identifier, in raw SAX events.
XmlTransformer | Return the raw XML string of the record
LxmlXsltTransformer | XSLT transformer using Lxml implementation.
XsltTransformer | 4Suite based XSLT transformer.
CSVTransformer | Create simple CSV format from indexes specified
GRS1Transformer | Create representation of the XML tree in Z39.50's GRS1 format
GrsMapTransformer | Create a particular GRS1 instance, based on a configured map of XPath to GRS1 element.
XmlRecordStoreTransformer | Wrap the data with the record's metadata.